/*====================================================================*
 -  Copyright (C) 2001 Leptonica.  All rights reserved.
 -
 -  Redistribution and use in source and binary forms, with or without
 -  modification, are permitted provided that the following conditions
 -  are met:
 -  1. Redistributions of source code must retain the above copyright
 -     notice, this list of conditions and the following disclaimer.
 -  2. Redistributions in binary form must reproduce the above
 -     copyright notice, this list of conditions and the following
 -     disclaimer in the documentation and/or other materials
 -     provided with the distribution.
 -
 -  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 -  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 -  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 -  A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ANY
 -  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 -  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 -  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 -  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 -  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 -  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *====================================================================*/

/*
 * converttopdf.c
 *
 *    Bundles all image files that are in the current directory, with
 *    optional matching substring, into a pdf.
 *
 *    Default values are used for encoding type, the resolution
 *    is set at 300 ppi if not given in the individual images,
 *    and the images are wrapped at full resolution.  No title
 *    is attached.
 *
 *    This is meant for the simplest set of input arguments.
 *    The syntax for all files in the directory is:
 *         convertopdf <pdf_outfile>
 *    The syntax using some substring to be matched in the file names is:
 *         converttopdf <substring> <pdf_outfile>
 *    If you want something more general, use convertfilestopdf.
 */

#include <string.h>
#include "allheaders.h"

int main(int    argc,
         char **argv)
{
l_int32  ret;
char    *substr, *fileout;

    if (argc != 2 && argc != 3) {
        fprintf(stderr,
            " Syntax: converttopdf [substr] fileout\n"
            "         substr:  Leave this out to bundle all files\n"
            "         fileout:  Output pdf file\n");
        return 1;
    }

    substr = (argc == 3) ? argv[1] : NULL;
    fileout = (argc == 3) ? argv[2] : argv[1];
    ret = convertFilesToPdf(".", substr, 300, 1.0, 0, 0, NULL, fileout);
    return ret;
}
